@@ -868,7 +868,7 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 		{
 			* (GokKeyboardDirection *) pKey->pGeneral = 
 				gok_keyboard_parse_direction (pStringSubAttributeValue);
-			g_free (pStringSubAttributeValue);
+			xmlFree (pStringSubAttributeValue);
 		}
 	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"move-resize") == 0)
@@ -882,7 +882,7 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 		{
 			* (GokKeyboardDirection *) pKey->pGeneral = 
 				gok_keyboard_parse_direction (pStringSubAttributeValue);
-			g_free (pStringSubAttributeValue);
+			xmlFree (pStringSubAttributeValue);
 		}
 		pKey->is_repeatable = TRUE;
 	}
@@ -921,7 +921,7 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 		{
 			* (GokKeyboardValueOp *) pKey->pGeneral = 
 				gok_keyboard_parse_value_op (pStringSubAttributeValue);
-			g_free (pStringSubAttributeValue);
+			xmlFree (pStringSubAttributeValue);
 		}
 	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"select") == 0)
@@ -1792,6 +1792,7 @@ void gok_key_set_button_name (GokKey* pKey)
 		strcpy (styleText, "StyleTextNormal");
 		break;
 					
+	case KEYSTYLE_ADDWORD:
 	case KEYSTYLE_HELP:
 		strcpy (styleButton, "StyleButtonHelp");
 		strcpy (styleText, "StyleTextHelp");
