@@ -346,7 +346,7 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 			
 			gok_log ("Sending a keysym");
 			gok_log ("pOutput->Name = %s", pOutput->Name);
-			gok_log ("SPI_KEY_SYM = %d", (int) SPI_KEY_SYM);
+			gok_log ("SPI_KEY_SYM = %d", (int) keysym);
 
 			SPI_generateKeyboardEvent ((long) keysym, NULL, SPI_KEY_SYM);
 
