@@ -688,7 +688,9 @@ gok_spy_get_list_parent (Accessible *search_root)
 		gok_spy_accessible_implicit_ref (child);
 		role = Accessible_getRole (child);
 		if (role == SPI_ROLE_LIST_ITEM
-		    || role == SPI_ROLE_MENU_ITEM)
+		    || role == SPI_ROLE_MENU_ITEM
+		    || role == SPI_ROLE_RADIO_MENU_ITEM
+		    || role == SPI_ROLE_CHECK_MENU_ITEM)
 		{
 		    gok_spy_accessible_unref (child);
 		    return search_root;
