@@ -133,6 +133,7 @@ typedef struct _GokArgs {
 	char* selectactionname;
 	gboolean list_actions;
 	gboolean list_accessmethods;
+	gdouble valuator_sensitivity;
 } GokArgs;
 
 static GokArgs gok_args;
@@ -272,6 +273,15 @@ static struct poptOption options[] = {
 		N_("Open the settings dialog box when GOK starts"),
 		NULL
 	},
+	{
+		"valuator-sensitivity", 
+		'\0', 
+		POPT_ARG_DOUBLE, 
+		&gok_args.valuator_sensitivity, 
+		0,
+		N_("A multiplier to be applied to input device valuator events before processing"),
+		NULL
+	},
 
 	/* End the list */
 	{NULL, '\0', 0, NULL, 0, NULL, NULL}
@@ -323,6 +333,7 @@ gok_args_init (GokArgs *args)
 	args->use_extras = FALSE;
 	args->scanactionname = NULL;
 	args->selectactionname = NULL;
+	args->valuator_sensitivity = 0;
 }
 
 /* callback for gok window state events */
@@ -2625,6 +2636,19 @@ gok_main_get_select_override (void)
 	return gok_args.selectactionname;
 }
 
+/**
+* gok_main_get_valuatorsensitivity_override
+*
+* Call this to see if a valuator sensitivity multiplier was passed in from the command line
+*
+* returns: gdouble multiplier
+*/
+gdouble
+gok_main_get_valuatorsensitivity_override (void)
+{
+	return gok_args.valuator_sensitivity;
+}
+
 /**
 * gok_main_get_geometry
 *
